﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace ScrollbarTrackPositionDemo
{
    public partial class Form1 : Form
    {
        [DllImport("user32.dll")]
        [return: MarshalAs(UnmanagedType.Bool)]
        private static extern bool GetScrollInfo(IntPtr hwnd, int fnBar, ref SCROLLINFO lpsi);

        [Serializable, StructLayout(LayoutKind.Sequential)]
        struct SCROLLINFO
        {
            public uint cbSize;
            public uint fMask;
            public int nMin;
            public int nMax;
            public uint nPage;
            public int nPos;
            public int nTrackPos;
        }

        public enum ScrollInfoMask : uint
        {
            SIF_RANGE = 0x1,
            SIF_PAGE = 0x2,
            SIF_POS = 0x4,
            SIF_DISABLENOSCROLL = 0x8,
            SIF_TRACKPOS = 0x10,
            SIF_ALL = (SIF_RANGE | SIF_PAGE | SIF_POS | SIF_TRACKPOS),
        }

        private void ShowTrackPosition()
        {
            SCROLLINFO si = new SCROLLINFO();
            si.cbSize = (uint)Marshal.SizeOf(si);
            si.fMask = (uint)ScrollInfoMask.SIF_ALL;

            GetScrollInfo(flowLayoutPanel1.Handle, (int)System.Windows.Forms.Orientation.Horizontal, ref si);

            lblTrackPos.Text = si.nTrackPos.ToString();
            lblScrollPos.Text = flowLayoutPanel1.HorizontalScroll.Value.ToString();
        }

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            for (int k = 0; k < 50; k++)
            {
                CustomPictureBox pb=new CustomPictureBox();
                pb.Tag = (k + 1).ToString();
                pb.BackColor = Color.Yellow;
                pb.Width = 139;
                pb.Height = 90;                
                pb.BorderStyle = BorderStyle.Fixed3D;

                flowLayoutPanel1.Controls.Add(pb);
                pb.Visible = true;
            }
        }



        private void flowLayoutPanel1_Scroll(object sender, ScrollEventArgs e)
        {
            ShowTrackPosition();
        }
    }

    public class CustomPictureBox : PictureBox
    {
        public CustomPictureBox()
            : base()
        {

        }

        protected override void OnPaint(PaintEventArgs pe)
        {
            base.OnPaint(pe);

            string tag=this.Tag.ToString();

            SizeF sz=pe.Graphics.MeasureString(tag,new System.Drawing.Font(DefaultFont.FontFamily,24,FontStyle.Bold));

            pe.Graphics.DrawString(tag, new System.Drawing.Font(DefaultFont.FontFamily, 24, FontStyle.Bold), Brushes.Black, new PointF(this.Width / 2 - sz.Width / 2, this.Height / 2 - sz.Height / 2));
        }

    }
}
